Skip to contents

Prints the component table from effective_df() followed by summary lines with the number of sample statistics, the nominal and effective model degrees of freedom, and the penalty settings.

Usage

# S3 method for class 'plavaan_efdf'
print(x, ...)

Arguments

x

An object of class plavaan_efdf, typically the return value of effective_df().

...

Passed to print.data.frame().